# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: capsule8/api/v0/types.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='capsule8/api/v0/types.proto',
  package='capsule8.api.v0',
  syntax='proto3',
  serialized_pb=_b('\n\x1b\x63\x61psule8/api/v0/types.proto\x12\x0f\x63\x61psule8.api.v0\"\x1e\n\x0bIPv4Address\x12\x0f\n\x07\x61\x64\x64ress\x18\x01 \x01(\x07\"Q\n\x12IPv4AddressAndPort\x12-\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1c.capsule8.api.v0.IPv4Address\x12\x0c\n\x04port\x18\x02 \x01(\r\"(\n\x0bIPv6Address\x12\x0c\n\x04high\x18\x01 \x01(\x06\x12\x0b\n\x03low\x18\x02 \x01(\x06\"Q\n\x12IPv6AddressAndPort\x12-\n\x07\x61\x64\x64ress\x18\x01 \x01(\x0b\x32\x1c.capsule8.api.v0.IPv6Address\x12\x0c\n\x04port\x18\x02 \x01(\r\"\xe5\x01\n\x0eNetworkAddress\x12\x35\n\x06\x66\x61mily\x18\x01 \x01(\x0e\x32%.capsule8.api.v0.NetworkAddressFamily\x12;\n\x0cipv4_address\x18\n \x01(\x0b\x32#.capsule8.api.v0.IPv4AddressAndPortH\x00\x12;\n\x0cipv6_address\x18\x14 \x01(\x0b\x32#.capsule8.api.v0.IPv6AddressAndPortH\x00\x12\x17\n\rlocal_address\x18\x1e \x01(\tH\x00\x42\t\n\x07\x61\x64\x64ress\"}\n\x0b\x43redentials\x12\x0b\n\x03uid\x18\x01 \x01(\r\x12\x0b\n\x03gid\x18\x02 \x01(\r\x12\x0c\n\x04\x65uid\x18\x03 \x01(\r\x12\x0c\n\x04\x65gid\x18\x04 \x01(\r\x12\x0c\n\x04suid\x18\x05 \x01(\r\x12\x0c\n\x04sgid\x18\x06 \x01(\r\x12\r\n\x05\x66suid\x18\x07 \x01(\r\x12\r\n\x05\x66sgid\x18\x08 \x01(\r*\x9f\x01\n\x14NetworkAddressFamily\x12\"\n\x1eNETWORK_ADDRESS_FAMILY_UNKNOWN\x10\x00\x12\x1f\n\x1bNETWORK_ADDRESS_FAMILY_INET\x10\x01\x12 \n\x1cNETWORK_ADDRESS_FAMILY_INET6\x10\x02\x12 \n\x1cNETWORK_ADDRESS_FAMILY_LOCAL\x10\x03\x62\x06proto3')
)

_NETWORKADDRESSFAMILY = _descriptor.EnumDescriptor(
  name='NetworkAddressFamily',
  full_name='capsule8.api.v0.NetworkAddressFamily',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NETWORK_ADDRESS_FAMILY_UNKNOWN', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NETWORK_ADDRESS_FAMILY_INET', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NETWORK_ADDRESS_FAMILY_INET6', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NETWORK_ADDRESS_FAMILY_LOCAL', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=648,
  serialized_end=807,
)
_sym_db.RegisterEnumDescriptor(_NETWORKADDRESSFAMILY)

NetworkAddressFamily = enum_type_wrapper.EnumTypeWrapper(_NETWORKADDRESSFAMILY)
NETWORK_ADDRESS_FAMILY_UNKNOWN = 0
NETWORK_ADDRESS_FAMILY_INET = 1
NETWORK_ADDRESS_FAMILY_INET6 = 2
NETWORK_ADDRESS_FAMILY_LOCAL = 3



_IPV4ADDRESS = _descriptor.Descriptor(
  name='IPv4Address',
  full_name='capsule8.api.v0.IPv4Address',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='capsule8.api.v0.IPv4Address.address', index=0,
      number=1, type=7, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=48,
  serialized_end=78,
)


_IPV4ADDRESSANDPORT = _descriptor.Descriptor(
  name='IPv4AddressAndPort',
  full_name='capsule8.api.v0.IPv4AddressAndPort',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='capsule8.api.v0.IPv4AddressAndPort.address', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='capsule8.api.v0.IPv4AddressAndPort.port', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=161,
)


_IPV6ADDRESS = _descriptor.Descriptor(
  name='IPv6Address',
  full_name='capsule8.api.v0.IPv6Address',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='high', full_name='capsule8.api.v0.IPv6Address.high', index=0,
      number=1, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='low', full_name='capsule8.api.v0.IPv6Address.low', index=1,
      number=2, type=6, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=163,
  serialized_end=203,
)


_IPV6ADDRESSANDPORT = _descriptor.Descriptor(
  name='IPv6AddressAndPort',
  full_name='capsule8.api.v0.IPv6AddressAndPort',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='address', full_name='capsule8.api.v0.IPv6AddressAndPort.address', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='port', full_name='capsule8.api.v0.IPv6AddressAndPort.port', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=205,
  serialized_end=286,
)


_NETWORKADDRESS = _descriptor.Descriptor(
  name='NetworkAddress',
  full_name='capsule8.api.v0.NetworkAddress',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='family', full_name='capsule8.api.v0.NetworkAddress.family', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ipv4_address', full_name='capsule8.api.v0.NetworkAddress.ipv4_address', index=1,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ipv6_address', full_name='capsule8.api.v0.NetworkAddress.ipv6_address', index=2,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='local_address', full_name='capsule8.api.v0.NetworkAddress.local_address', index=3,
      number=30, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='address', full_name='capsule8.api.v0.NetworkAddress.address',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=289,
  serialized_end=518,
)


_CREDENTIALS = _descriptor.Descriptor(
  name='Credentials',
  full_name='capsule8.api.v0.Credentials',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uid', full_name='capsule8.api.v0.Credentials.uid', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gid', full_name='capsule8.api.v0.Credentials.gid', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='euid', full_name='capsule8.api.v0.Credentials.euid', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='egid', full_name='capsule8.api.v0.Credentials.egid', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='suid', full_name='capsule8.api.v0.Credentials.suid', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sgid', full_name='capsule8.api.v0.Credentials.sgid', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fsuid', full_name='capsule8.api.v0.Credentials.fsuid', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fsgid', full_name='capsule8.api.v0.Credentials.fsgid', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=520,
  serialized_end=645,
)

_IPV4ADDRESSANDPORT.fields_by_name['address'].message_type = _IPV4ADDRESS
_IPV6ADDRESSANDPORT.fields_by_name['address'].message_type = _IPV6ADDRESS
_NETWORKADDRESS.fields_by_name['family'].enum_type = _NETWORKADDRESSFAMILY
_NETWORKADDRESS.fields_by_name['ipv4_address'].message_type = _IPV4ADDRESSANDPORT
_NETWORKADDRESS.fields_by_name['ipv6_address'].message_type = _IPV6ADDRESSANDPORT
_NETWORKADDRESS.oneofs_by_name['address'].fields.append(
  _NETWORKADDRESS.fields_by_name['ipv4_address'])
_NETWORKADDRESS.fields_by_name['ipv4_address'].containing_oneof = _NETWORKADDRESS.oneofs_by_name['address']
_NETWORKADDRESS.oneofs_by_name['address'].fields.append(
  _NETWORKADDRESS.fields_by_name['ipv6_address'])
_NETWORKADDRESS.fields_by_name['ipv6_address'].containing_oneof = _NETWORKADDRESS.oneofs_by_name['address']
_NETWORKADDRESS.oneofs_by_name['address'].fields.append(
  _NETWORKADDRESS.fields_by_name['local_address'])
_NETWORKADDRESS.fields_by_name['local_address'].containing_oneof = _NETWORKADDRESS.oneofs_by_name['address']
DESCRIPTOR.message_types_by_name['IPv4Address'] = _IPV4ADDRESS
DESCRIPTOR.message_types_by_name['IPv4AddressAndPort'] = _IPV4ADDRESSANDPORT
DESCRIPTOR.message_types_by_name['IPv6Address'] = _IPV6ADDRESS
DESCRIPTOR.message_types_by_name['IPv6AddressAndPort'] = _IPV6ADDRESSANDPORT
DESCRIPTOR.message_types_by_name['NetworkAddress'] = _NETWORKADDRESS
DESCRIPTOR.message_types_by_name['Credentials'] = _CREDENTIALS
DESCRIPTOR.enum_types_by_name['NetworkAddressFamily'] = _NETWORKADDRESSFAMILY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

IPv4Address = _reflection.GeneratedProtocolMessageType('IPv4Address', (_message.Message,), dict(
  DESCRIPTOR = _IPV4ADDRESS,
  __module__ = 'capsule8.api.v0.types_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.IPv4Address)
  ))
_sym_db.RegisterMessage(IPv4Address)

IPv4AddressAndPort = _reflection.GeneratedProtocolMessageType('IPv4AddressAndPort', (_message.Message,), dict(
  DESCRIPTOR = _IPV4ADDRESSANDPORT,
  __module__ = 'capsule8.api.v0.types_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.IPv4AddressAndPort)
  ))
_sym_db.RegisterMessage(IPv4AddressAndPort)

IPv6Address = _reflection.GeneratedProtocolMessageType('IPv6Address', (_message.Message,), dict(
  DESCRIPTOR = _IPV6ADDRESS,
  __module__ = 'capsule8.api.v0.types_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.IPv6Address)
  ))
_sym_db.RegisterMessage(IPv6Address)

IPv6AddressAndPort = _reflection.GeneratedProtocolMessageType('IPv6AddressAndPort', (_message.Message,), dict(
  DESCRIPTOR = _IPV6ADDRESSANDPORT,
  __module__ = 'capsule8.api.v0.types_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.IPv6AddressAndPort)
  ))
_sym_db.RegisterMessage(IPv6AddressAndPort)

NetworkAddress = _reflection.GeneratedProtocolMessageType('NetworkAddress', (_message.Message,), dict(
  DESCRIPTOR = _NETWORKADDRESS,
  __module__ = 'capsule8.api.v0.types_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.NetworkAddress)
  ))
_sym_db.RegisterMessage(NetworkAddress)

Credentials = _reflection.GeneratedProtocolMessageType('Credentials', (_message.Message,), dict(
  DESCRIPTOR = _CREDENTIALS,
  __module__ = 'capsule8.api.v0.types_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.Credentials)
  ))
_sym_db.RegisterMessage(Credentials)


# @@protoc_insertion_point(module_scope)
