# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: capsule8/api/v0/subscription.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from capsule8.api.v0 import telemetry_event_pb2 as capsule8_dot_api_dot_v0_dot_telemetry__event__pb2
from capsule8.api.v0 import expression_pb2 as capsule8_dot_api_dot_v0_dot_expression__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='capsule8/api/v0/subscription.proto',
  package='capsule8.api.v0',
  syntax='proto3',
  serialized_pb=_b('\n\"capsule8/api/v0/subscription.proto\x12\x0f\x63\x61psule8.api.v0\x1a%capsule8/api/v0/telemetry_event.proto\x1a capsule8/api/v0/expression.proto\x1a\x1egoogle/protobuf/wrappers.proto\"\x93\x02\n\x0cSubscription\x12\x32\n\x0c\x65vent_filter\x18\x01 \x01(\x0b\x32\x1c.capsule8.api.v0.EventFilter\x12:\n\x10\x63ontainer_filter\x18\x02 \x01(\x0b\x32 .capsule8.api.v0.ContainerFilter\x12\x33\n\x0esince_duration\x18\n \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x31\n\x0c\x66or_duration\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12+\n\x08modifier\x18\x14 \x01(\x0b\x32\x19.capsule8.api.v0.Modifier\"U\n\x0f\x43ontainerFilter\x12\x0b\n\x03ids\x18\x01 \x03(\t\x12\r\n\x05names\x18\x02 \x03(\t\x12\x11\n\timage_ids\x18\x03 \x03(\t\x12\x13\n\x0bimage_names\x18\x04 \x03(\t\"\xbb\x04\n\x0b\x45ventFilter\x12;\n\x0esyscall_events\x18\x01 \x03(\x0b\x32#.capsule8.api.v0.SyscallEventFilter\x12;\n\x0eprocess_events\x18\x02 \x03(\x0b\x32#.capsule8.api.v0.ProcessEventFilter\x12\x35\n\x0b\x66ile_events\x18\x03 \x03(\x0b\x32 .capsule8.api.v0.FileEventFilter\x12@\n\rkernel_events\x18\x04 \x03(\x0b\x32).capsule8.api.v0.KernelFunctionCallFilter\x12;\n\x0enetwork_events\x18\x05 \x03(\x0b\x32#.capsule8.api.v0.NetworkEventFilter\x12\x43\n\x12performance_events\x18\x06 \x03(\x0b\x32\'.capsule8.api.v0.PerformanceEventFilter\x12?\n\x10\x63ontainer_events\x18\n \x03(\x0b\x32%.capsule8.api.v0.ContainerEventFilter\x12;\n\x0e\x63hargen_events\x18\x64 \x03(\x0b\x32#.capsule8.api.v0.ChargenEventFilter\x12\x39\n\rticker_events\x18\x65 \x03(\x0b\x32\".capsule8.api.v0.TickerEventFilter\"\xd8\x03\n\x12SyscallEventFilter\x12/\n\x04type\x18\x01 \x01(\x0e\x32!.capsule8.api.v0.SyscallEventType\x12\x36\n\x11\x66ilter_expression\x18\x64 \x01(\x0b\x32\x1b.capsule8.api.v0.Expression\x12\'\n\x02id\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12*\n\x04\x61rg0\x18\n \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12*\n\x04\x61rg1\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12*\n\x04\x61rg2\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12*\n\x04\x61rg3\x18\r \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12*\n\x04\x61rg4\x18\x0e \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12*\n\x04\x61rg5\x18\x0f \x01(\x0b\x32\x1c.google.protobuf.UInt64Value\x12(\n\x03ret\x18\x14 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\"\x9f\x02\n\x12ProcessEventFilter\x12/\n\x04type\x18\x01 \x01(\x0e\x32!.capsule8.api.v0.ProcessEventType\x12\x36\n\x11\x66ilter_expression\x18\x64 \x01(\x0b\x32\x1b.capsule8.api.v0.Expression\x12\x33\n\rexec_filename\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12;\n\x15\x65xec_filename_pattern\x18\r \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12.\n\texit_code\x18\x0e \x01(\x0b\x32\x1b.google.protobuf.Int32Value\"\xcc\x02\n\x0f\x46ileEventFilter\x12,\n\x04type\x18\x01 \x01(\x0e\x32\x1e.capsule8.api.v0.FileEventType\x12\x36\n\x11\x66ilter_expression\x18\x64 \x01(\x0b\x32\x1b.capsule8.api.v0.Expression\x12.\n\x08\x66ilename\x18\n \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x36\n\x10\x66ilename_pattern\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x34\n\x0fopen_flags_mask\x18\x0c \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12\x35\n\x10\x63reate_mode_mask\x18\r \x01(\x0b\x32\x1b.google.protobuf.Int32Value\"\x9d\x02\n\x18KernelFunctionCallFilter\x12:\n\x04type\x18\x01 \x01(\x0e\x32,.capsule8.api.v0.KernelFunctionCallEventType\x12\x0e\n\x06symbol\x18\n \x01(\t\x12K\n\targuments\x18\x0b \x03(\x0b\x32\x38.capsule8.api.v0.KernelFunctionCallFilter.ArgumentsEntry\x12\x36\n\x11\x66ilter_expression\x18\x64 \x01(\x0b\x32\x1b.capsule8.api.v0.Expression\x1a\x30\n\x0e\x41rgumentsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"}\n\x12NetworkEventFilter\x12/\n\x04type\x18\x01 \x01(\x0e\x32!.capsule8.api.v0.NetworkEventType\x12\x36\n\x11\x66ilter_expression\x18\x64 \x01(\x0b\x32\x1b.capsule8.api.v0.Expression\"^\n\x17PerformanceEventCounter\x12\x33\n\x04type\x18\x01 \x01(\x0e\x32%.capsule8.api.v0.PerformanceEventType\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\x04\"\xc3\x01\n\x16PerformanceEventFilter\x12\x38\n\x06\x65vents\x18\n \x03(\x0b\x32(.capsule8.api.v0.PerformanceEventCounter\x12\x39\n\x10sample_rate_type\x18\x0b \x01(\x0e\x32\x1f.capsule8.api.v0.SampleRateType\x12\x10\n\x06period\x18\x0c \x01(\x04H\x00\x12\x13\n\tfrequency\x18\r \x01(\x04H\x00\x42\r\n\x0bsample_rate\"\xb4\x01\n\x14\x43ontainerEventFilter\x12\x31\n\x04type\x18\x01 \x01(\x0e\x32#.capsule8.api.v0.ContainerEventType\x12\x31\n\x04view\x18\x02 \x01(\x0e\x32#.capsule8.api.v0.ContainerEventView\x12\x36\n\x11\x66ilter_expression\x18\x64 \x01(\x0b\x32\x1b.capsule8.api.v0.Expression\"$\n\x12\x43hargenEventFilter\x12\x0e\n\x06length\x18\x01 \x01(\x04\"%\n\x11TickerEventFilter\x12\x10\n\x08interval\x18\x01 \x01(\x03\"n\n\x08Modifier\x12\x33\n\x08throttle\x18\x01 \x01(\x0b\x32!.capsule8.api.v0.ThrottleModifier\x12-\n\x05limit\x18\x02 \x01(\x0b\x32\x1e.capsule8.api.v0.LimitModifier\"\xae\x01\n\x10ThrottleModifier\x12\x10\n\x08interval\x18\x01 \x01(\x03\x12\x45\n\rinterval_type\x18\x02 \x01(\x0e\x32..capsule8.api.v0.ThrottleModifier.IntervalType\"A\n\x0cIntervalType\x12\x0f\n\x0bMILLISECOND\x10\x00\x12\n\n\x06SECOND\x10\x01\x12\n\n\x06MINUTE\x10\x02\x12\x08\n\x04HOUR\x10\x03\"\x1e\n\rLimitModifier\x12\r\n\x05limit\x18\x01 \x01(\x03*k\n\x0eSampleRateType\x12\x1c\n\x18SAMPLE_RATE_TYPE_UNKNOWN\x10\x00\x12\x1b\n\x17SAMPLE_RATE_TYPE_PERIOD\x10\x01\x12\x1e\n\x1aSAMPLE_RATE_TYPE_FREQUENCY\x10\x02*)\n\x12\x43ontainerEventView\x12\t\n\x05\x42\x41SIC\x10\x00\x12\x08\n\x04\x46ULL\x10\x01\x62\x06proto3')
  ,
  dependencies=[capsule8_dot_api_dot_v0_dot_telemetry__event__pb2.DESCRIPTOR,capsule8_dot_api_dot_v0_dot_expression__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,])

_SAMPLERATETYPE = _descriptor.EnumDescriptor(
  name='SampleRateType',
  full_name='capsule8.api.v0.SampleRateType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SAMPLE_RATE_TYPE_UNKNOWN', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SAMPLE_RATE_TYPE_PERIOD', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SAMPLE_RATE_TYPE_FREQUENCY', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3489,
  serialized_end=3596,
)
_sym_db.RegisterEnumDescriptor(_SAMPLERATETYPE)

SampleRateType = enum_type_wrapper.EnumTypeWrapper(_SAMPLERATETYPE)
_CONTAINEREVENTVIEW = _descriptor.EnumDescriptor(
  name='ContainerEventView',
  full_name='capsule8.api.v0.ContainerEventView',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='BASIC', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FULL', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3598,
  serialized_end=3639,
)
_sym_db.RegisterEnumDescriptor(_CONTAINEREVENTVIEW)

ContainerEventView = enum_type_wrapper.EnumTypeWrapper(_CONTAINEREVENTVIEW)
SAMPLE_RATE_TYPE_UNKNOWN = 0
SAMPLE_RATE_TYPE_PERIOD = 1
SAMPLE_RATE_TYPE_FREQUENCY = 2
BASIC = 0
FULL = 1


_THROTTLEMODIFIER_INTERVALTYPE = _descriptor.EnumDescriptor(
  name='IntervalType',
  full_name='capsule8.api.v0.ThrottleModifier.IntervalType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='MILLISECOND', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SECOND', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MINUTE', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HOUR', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3390,
  serialized_end=3455,
)
_sym_db.RegisterEnumDescriptor(_THROTTLEMODIFIER_INTERVALTYPE)


_SUBSCRIPTION = _descriptor.Descriptor(
  name='Subscription',
  full_name='capsule8.api.v0.Subscription',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_filter', full_name='capsule8.api.v0.Subscription.event_filter', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='container_filter', full_name='capsule8.api.v0.Subscription.container_filter', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='since_duration', full_name='capsule8.api.v0.Subscription.since_duration', index=2,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='for_duration', full_name='capsule8.api.v0.Subscription.for_duration', index=3,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='modifier', full_name='capsule8.api.v0.Subscription.modifier', index=4,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=161,
  serialized_end=436,
)


_CONTAINERFILTER = _descriptor.Descriptor(
  name='ContainerFilter',
  full_name='capsule8.api.v0.ContainerFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ids', full_name='capsule8.api.v0.ContainerFilter.ids', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='names', full_name='capsule8.api.v0.ContainerFilter.names', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_ids', full_name='capsule8.api.v0.ContainerFilter.image_ids', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='image_names', full_name='capsule8.api.v0.ContainerFilter.image_names', index=3,
      number=4, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=438,
  serialized_end=523,
)


_EVENTFILTER = _descriptor.Descriptor(
  name='EventFilter',
  full_name='capsule8.api.v0.EventFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='syscall_events', full_name='capsule8.api.v0.EventFilter.syscall_events', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='process_events', full_name='capsule8.api.v0.EventFilter.process_events', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='file_events', full_name='capsule8.api.v0.EventFilter.file_events', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='kernel_events', full_name='capsule8.api.v0.EventFilter.kernel_events', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='network_events', full_name='capsule8.api.v0.EventFilter.network_events', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='performance_events', full_name='capsule8.api.v0.EventFilter.performance_events', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='container_events', full_name='capsule8.api.v0.EventFilter.container_events', index=6,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chargen_events', full_name='capsule8.api.v0.EventFilter.chargen_events', index=7,
      number=100, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ticker_events', full_name='capsule8.api.v0.EventFilter.ticker_events', index=8,
      number=101, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=526,
  serialized_end=1097,
)


_SYSCALLEVENTFILTER = _descriptor.Descriptor(
  name='SyscallEventFilter',
  full_name='capsule8.api.v0.SyscallEventFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='capsule8.api.v0.SyscallEventFilter.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filter_expression', full_name='capsule8.api.v0.SyscallEventFilter.filter_expression', index=1,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='capsule8.api.v0.SyscallEventFilter.id', index=2,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arg0', full_name='capsule8.api.v0.SyscallEventFilter.arg0', index=3,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arg1', full_name='capsule8.api.v0.SyscallEventFilter.arg1', index=4,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arg2', full_name='capsule8.api.v0.SyscallEventFilter.arg2', index=5,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arg3', full_name='capsule8.api.v0.SyscallEventFilter.arg3', index=6,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arg4', full_name='capsule8.api.v0.SyscallEventFilter.arg4', index=7,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arg5', full_name='capsule8.api.v0.SyscallEventFilter.arg5', index=8,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ret', full_name='capsule8.api.v0.SyscallEventFilter.ret', index=9,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1100,
  serialized_end=1572,
)


_PROCESSEVENTFILTER = _descriptor.Descriptor(
  name='ProcessEventFilter',
  full_name='capsule8.api.v0.ProcessEventFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='capsule8.api.v0.ProcessEventFilter.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filter_expression', full_name='capsule8.api.v0.ProcessEventFilter.filter_expression', index=1,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exec_filename', full_name='capsule8.api.v0.ProcessEventFilter.exec_filename', index=2,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exec_filename_pattern', full_name='capsule8.api.v0.ProcessEventFilter.exec_filename_pattern', index=3,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exit_code', full_name='capsule8.api.v0.ProcessEventFilter.exit_code', index=4,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1575,
  serialized_end=1862,
)


_FILEEVENTFILTER = _descriptor.Descriptor(
  name='FileEventFilter',
  full_name='capsule8.api.v0.FileEventFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='capsule8.api.v0.FileEventFilter.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filter_expression', full_name='capsule8.api.v0.FileEventFilter.filter_expression', index=1,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filename', full_name='capsule8.api.v0.FileEventFilter.filename', index=2,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filename_pattern', full_name='capsule8.api.v0.FileEventFilter.filename_pattern', index=3,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open_flags_mask', full_name='capsule8.api.v0.FileEventFilter.open_flags_mask', index=4,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='create_mode_mask', full_name='capsule8.api.v0.FileEventFilter.create_mode_mask', index=5,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1865,
  serialized_end=2197,
)


_KERNELFUNCTIONCALLFILTER_ARGUMENTSENTRY = _descriptor.Descriptor(
  name='ArgumentsEntry',
  full_name='capsule8.api.v0.KernelFunctionCallFilter.ArgumentsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='capsule8.api.v0.KernelFunctionCallFilter.ArgumentsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='capsule8.api.v0.KernelFunctionCallFilter.ArgumentsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=_descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001')),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2437,
  serialized_end=2485,
)

_KERNELFUNCTIONCALLFILTER = _descriptor.Descriptor(
  name='KernelFunctionCallFilter',
  full_name='capsule8.api.v0.KernelFunctionCallFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='capsule8.api.v0.KernelFunctionCallFilter.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='symbol', full_name='capsule8.api.v0.KernelFunctionCallFilter.symbol', index=1,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arguments', full_name='capsule8.api.v0.KernelFunctionCallFilter.arguments', index=2,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filter_expression', full_name='capsule8.api.v0.KernelFunctionCallFilter.filter_expression', index=3,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_KERNELFUNCTIONCALLFILTER_ARGUMENTSENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2200,
  serialized_end=2485,
)


_NETWORKEVENTFILTER = _descriptor.Descriptor(
  name='NetworkEventFilter',
  full_name='capsule8.api.v0.NetworkEventFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='capsule8.api.v0.NetworkEventFilter.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filter_expression', full_name='capsule8.api.v0.NetworkEventFilter.filter_expression', index=1,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2487,
  serialized_end=2612,
)


_PERFORMANCEEVENTCOUNTER = _descriptor.Descriptor(
  name='PerformanceEventCounter',
  full_name='capsule8.api.v0.PerformanceEventCounter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='capsule8.api.v0.PerformanceEventCounter.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='config', full_name='capsule8.api.v0.PerformanceEventCounter.config', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2614,
  serialized_end=2708,
)


_PERFORMANCEEVENTFILTER = _descriptor.Descriptor(
  name='PerformanceEventFilter',
  full_name='capsule8.api.v0.PerformanceEventFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='events', full_name='capsule8.api.v0.PerformanceEventFilter.events', index=0,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sample_rate_type', full_name='capsule8.api.v0.PerformanceEventFilter.sample_rate_type', index=1,
      number=11, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='period', full_name='capsule8.api.v0.PerformanceEventFilter.period', index=2,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='frequency', full_name='capsule8.api.v0.PerformanceEventFilter.frequency', index=3,
      number=13, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='sample_rate', full_name='capsule8.api.v0.PerformanceEventFilter.sample_rate',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=2711,
  serialized_end=2906,
)


_CONTAINEREVENTFILTER = _descriptor.Descriptor(
  name='ContainerEventFilter',
  full_name='capsule8.api.v0.ContainerEventFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='capsule8.api.v0.ContainerEventFilter.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='view', full_name='capsule8.api.v0.ContainerEventFilter.view', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='filter_expression', full_name='capsule8.api.v0.ContainerEventFilter.filter_expression', index=2,
      number=100, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2909,
  serialized_end=3089,
)


_CHARGENEVENTFILTER = _descriptor.Descriptor(
  name='ChargenEventFilter',
  full_name='capsule8.api.v0.ChargenEventFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='length', full_name='capsule8.api.v0.ChargenEventFilter.length', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3091,
  serialized_end=3127,
)


_TICKEREVENTFILTER = _descriptor.Descriptor(
  name='TickerEventFilter',
  full_name='capsule8.api.v0.TickerEventFilter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='interval', full_name='capsule8.api.v0.TickerEventFilter.interval', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3129,
  serialized_end=3166,
)


_MODIFIER = _descriptor.Descriptor(
  name='Modifier',
  full_name='capsule8.api.v0.Modifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='throttle', full_name='capsule8.api.v0.Modifier.throttle', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='capsule8.api.v0.Modifier.limit', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3168,
  serialized_end=3278,
)


_THROTTLEMODIFIER = _descriptor.Descriptor(
  name='ThrottleModifier',
  full_name='capsule8.api.v0.ThrottleModifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='interval', full_name='capsule8.api.v0.ThrottleModifier.interval', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='interval_type', full_name='capsule8.api.v0.ThrottleModifier.interval_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _THROTTLEMODIFIER_INTERVALTYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3281,
  serialized_end=3455,
)


_LIMITMODIFIER = _descriptor.Descriptor(
  name='LimitModifier',
  full_name='capsule8.api.v0.LimitModifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='limit', full_name='capsule8.api.v0.LimitModifier.limit', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3457,
  serialized_end=3487,
)

_SUBSCRIPTION.fields_by_name['event_filter'].message_type = _EVENTFILTER
_SUBSCRIPTION.fields_by_name['container_filter'].message_type = _CONTAINERFILTER
_SUBSCRIPTION.fields_by_name['since_duration'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_SUBSCRIPTION.fields_by_name['for_duration'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_SUBSCRIPTION.fields_by_name['modifier'].message_type = _MODIFIER
_EVENTFILTER.fields_by_name['syscall_events'].message_type = _SYSCALLEVENTFILTER
_EVENTFILTER.fields_by_name['process_events'].message_type = _PROCESSEVENTFILTER
_EVENTFILTER.fields_by_name['file_events'].message_type = _FILEEVENTFILTER
_EVENTFILTER.fields_by_name['kernel_events'].message_type = _KERNELFUNCTIONCALLFILTER
_EVENTFILTER.fields_by_name['network_events'].message_type = _NETWORKEVENTFILTER
_EVENTFILTER.fields_by_name['performance_events'].message_type = _PERFORMANCEEVENTFILTER
_EVENTFILTER.fields_by_name['container_events'].message_type = _CONTAINEREVENTFILTER
_EVENTFILTER.fields_by_name['chargen_events'].message_type = _CHARGENEVENTFILTER
_EVENTFILTER.fields_by_name['ticker_events'].message_type = _TICKEREVENTFILTER
_SYSCALLEVENTFILTER.fields_by_name['type'].enum_type = capsule8_dot_api_dot_v0_dot_telemetry__event__pb2._SYSCALLEVENTTYPE
_SYSCALLEVENTFILTER.fields_by_name['filter_expression'].message_type = capsule8_dot_api_dot_v0_dot_expression__pb2._EXPRESSION
_SYSCALLEVENTFILTER.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_SYSCALLEVENTFILTER.fields_by_name['arg0'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT64VALUE
_SYSCALLEVENTFILTER.fields_by_name['arg1'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT64VALUE
_SYSCALLEVENTFILTER.fields_by_name['arg2'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT64VALUE
_SYSCALLEVENTFILTER.fields_by_name['arg3'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT64VALUE
_SYSCALLEVENTFILTER.fields_by_name['arg4'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT64VALUE
_SYSCALLEVENTFILTER.fields_by_name['arg5'].message_type = google_dot_protobuf_dot_wrappers__pb2._UINT64VALUE
_SYSCALLEVENTFILTER.fields_by_name['ret'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_PROCESSEVENTFILTER.fields_by_name['type'].enum_type = capsule8_dot_api_dot_v0_dot_telemetry__event__pb2._PROCESSEVENTTYPE
_PROCESSEVENTFILTER.fields_by_name['filter_expression'].message_type = capsule8_dot_api_dot_v0_dot_expression__pb2._EXPRESSION
_PROCESSEVENTFILTER.fields_by_name['exec_filename'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PROCESSEVENTFILTER.fields_by_name['exec_filename_pattern'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PROCESSEVENTFILTER.fields_by_name['exit_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_FILEEVENTFILTER.fields_by_name['type'].enum_type = capsule8_dot_api_dot_v0_dot_telemetry__event__pb2._FILEEVENTTYPE
_FILEEVENTFILTER.fields_by_name['filter_expression'].message_type = capsule8_dot_api_dot_v0_dot_expression__pb2._EXPRESSION
_FILEEVENTFILTER.fields_by_name['filename'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FILEEVENTFILTER.fields_by_name['filename_pattern'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FILEEVENTFILTER.fields_by_name['open_flags_mask'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_FILEEVENTFILTER.fields_by_name['create_mode_mask'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_KERNELFUNCTIONCALLFILTER_ARGUMENTSENTRY.containing_type = _KERNELFUNCTIONCALLFILTER
_KERNELFUNCTIONCALLFILTER.fields_by_name['type'].enum_type = capsule8_dot_api_dot_v0_dot_telemetry__event__pb2._KERNELFUNCTIONCALLEVENTTYPE
_KERNELFUNCTIONCALLFILTER.fields_by_name['arguments'].message_type = _KERNELFUNCTIONCALLFILTER_ARGUMENTSENTRY
_KERNELFUNCTIONCALLFILTER.fields_by_name['filter_expression'].message_type = capsule8_dot_api_dot_v0_dot_expression__pb2._EXPRESSION
_NETWORKEVENTFILTER.fields_by_name['type'].enum_type = capsule8_dot_api_dot_v0_dot_telemetry__event__pb2._NETWORKEVENTTYPE
_NETWORKEVENTFILTER.fields_by_name['filter_expression'].message_type = capsule8_dot_api_dot_v0_dot_expression__pb2._EXPRESSION
_PERFORMANCEEVENTCOUNTER.fields_by_name['type'].enum_type = capsule8_dot_api_dot_v0_dot_telemetry__event__pb2._PERFORMANCEEVENTTYPE
_PERFORMANCEEVENTFILTER.fields_by_name['events'].message_type = _PERFORMANCEEVENTCOUNTER
_PERFORMANCEEVENTFILTER.fields_by_name['sample_rate_type'].enum_type = _SAMPLERATETYPE
_PERFORMANCEEVENTFILTER.oneofs_by_name['sample_rate'].fields.append(
  _PERFORMANCEEVENTFILTER.fields_by_name['period'])
_PERFORMANCEEVENTFILTER.fields_by_name['period'].containing_oneof = _PERFORMANCEEVENTFILTER.oneofs_by_name['sample_rate']
_PERFORMANCEEVENTFILTER.oneofs_by_name['sample_rate'].fields.append(
  _PERFORMANCEEVENTFILTER.fields_by_name['frequency'])
_PERFORMANCEEVENTFILTER.fields_by_name['frequency'].containing_oneof = _PERFORMANCEEVENTFILTER.oneofs_by_name['sample_rate']
_CONTAINEREVENTFILTER.fields_by_name['type'].enum_type = capsule8_dot_api_dot_v0_dot_telemetry__event__pb2._CONTAINEREVENTTYPE
_CONTAINEREVENTFILTER.fields_by_name['view'].enum_type = _CONTAINEREVENTVIEW
_CONTAINEREVENTFILTER.fields_by_name['filter_expression'].message_type = capsule8_dot_api_dot_v0_dot_expression__pb2._EXPRESSION
_MODIFIER.fields_by_name['throttle'].message_type = _THROTTLEMODIFIER
_MODIFIER.fields_by_name['limit'].message_type = _LIMITMODIFIER
_THROTTLEMODIFIER.fields_by_name['interval_type'].enum_type = _THROTTLEMODIFIER_INTERVALTYPE
_THROTTLEMODIFIER_INTERVALTYPE.containing_type = _THROTTLEMODIFIER
DESCRIPTOR.message_types_by_name['Subscription'] = _SUBSCRIPTION
DESCRIPTOR.message_types_by_name['ContainerFilter'] = _CONTAINERFILTER
DESCRIPTOR.message_types_by_name['EventFilter'] = _EVENTFILTER
DESCRIPTOR.message_types_by_name['SyscallEventFilter'] = _SYSCALLEVENTFILTER
DESCRIPTOR.message_types_by_name['ProcessEventFilter'] = _PROCESSEVENTFILTER
DESCRIPTOR.message_types_by_name['FileEventFilter'] = _FILEEVENTFILTER
DESCRIPTOR.message_types_by_name['KernelFunctionCallFilter'] = _KERNELFUNCTIONCALLFILTER
DESCRIPTOR.message_types_by_name['NetworkEventFilter'] = _NETWORKEVENTFILTER
DESCRIPTOR.message_types_by_name['PerformanceEventCounter'] = _PERFORMANCEEVENTCOUNTER
DESCRIPTOR.message_types_by_name['PerformanceEventFilter'] = _PERFORMANCEEVENTFILTER
DESCRIPTOR.message_types_by_name['ContainerEventFilter'] = _CONTAINEREVENTFILTER
DESCRIPTOR.message_types_by_name['ChargenEventFilter'] = _CHARGENEVENTFILTER
DESCRIPTOR.message_types_by_name['TickerEventFilter'] = _TICKEREVENTFILTER
DESCRIPTOR.message_types_by_name['Modifier'] = _MODIFIER
DESCRIPTOR.message_types_by_name['ThrottleModifier'] = _THROTTLEMODIFIER
DESCRIPTOR.message_types_by_name['LimitModifier'] = _LIMITMODIFIER
DESCRIPTOR.enum_types_by_name['SampleRateType'] = _SAMPLERATETYPE
DESCRIPTOR.enum_types_by_name['ContainerEventView'] = _CONTAINEREVENTVIEW
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Subscription = _reflection.GeneratedProtocolMessageType('Subscription', (_message.Message,), dict(
  DESCRIPTOR = _SUBSCRIPTION,
  __module__ = 'capsule8.api.v0.subscription_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.Subscription)
  ))
_sym_db.RegisterMessage(Subscription)

ContainerFilter = _reflection.GeneratedProtocolMessageType('ContainerFilter', (_message.Message,), dict(
  DESCRIPTOR = _CONTAINERFILTER,
  __module__ = 'capsule8.api.v0.subscription_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.ContainerFilter)
  ))
_sym_db.RegisterMessage(ContainerFilter)

EventFilter = _reflection.GeneratedProtocolMessageType('EventFilter', (_message.Message,), dict(
  DESCRIPTOR = _EVENTFILTER,
  __module__ = 'capsule8.api.v0.subscription_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.EventFilter)
  ))
_sym_db.RegisterMessage(EventFilter)

SyscallEventFilter = _reflection.GeneratedProtocolMessageType('SyscallEventFilter', (_message.Message,), dict(
  DESCRIPTOR = _SYSCALLEVENTFILTER,
  __module__ = 'capsule8.api.v0.subscription_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.SyscallEventFilter)
  ))
_sym_db.RegisterMessage(SyscallEventFilter)

ProcessEventFilter = _reflection.GeneratedProtocolMessageType('ProcessEventFilter', (_message.Message,), dict(
  DESCRIPTOR = _PROCESSEVENTFILTER,
  __module__ = 'capsule8.api.v0.subscription_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.ProcessEventFilter)
  ))
_sym_db.RegisterMessage(ProcessEventFilter)

FileEventFilter = _reflection.GeneratedProtocolMessageType('FileEventFilter', (_message.Message,), dict(
  DESCRIPTOR = _FILEEVENTFILTER,
  __module__ = 'capsule8.api.v0.subscription_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.FileEventFilter)
  ))
_sym_db.RegisterMessage(FileEventFilter)

KernelFunctionCallFilter = _reflection.GeneratedProtocolMessageType('KernelFunctionCallFilter', (_message.Message,), dict(

  ArgumentsEntry = _reflection.GeneratedProtocolMessageType('ArgumentsEntry', (_message.Message,), dict(
    DESCRIPTOR = _KERNELFUNCTIONCALLFILTER_ARGUMENTSENTRY,
    __module__ = 'capsule8.api.v0.subscription_pb2'
    # @@protoc_insertion_point(class_scope:capsule8.api.v0.KernelFunctionCallFilter.ArgumentsEntry)
    ))
  ,
  DESCRIPTOR = _KERNELFUNCTIONCALLFILTER,
  __module__ = 'capsule8.api.v0.subscription_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.KernelFunctionCallFilter)
  ))
_sym_db.RegisterMessage(KernelFunctionCallFilter)
_sym_db.RegisterMessage(KernelFunctionCallFilter.ArgumentsEntry)

NetworkEventFilter = _reflection.GeneratedProtocolMessageType('NetworkEventFilter', (_message.Message,), dict(
  DESCRIPTOR = _NETWORKEVENTFILTER,
  __module__ = 'capsule8.api.v0.subscription_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.NetworkEventFilter)
  ))
_sym_db.RegisterMessage(NetworkEventFilter)

PerformanceEventCounter = _reflection.GeneratedProtocolMessageType('PerformanceEventCounter', (_message.Message,), dict(
  DESCRIPTOR = _PERFORMANCEEVENTCOUNTER,
  __module__ = 'capsule8.api.v0.subscription_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.PerformanceEventCounter)
  ))
_sym_db.RegisterMessage(PerformanceEventCounter)

PerformanceEventFilter = _reflection.GeneratedProtocolMessageType('PerformanceEventFilter', (_message.Message,), dict(
  DESCRIPTOR = _PERFORMANCEEVENTFILTER,
  __module__ = 'capsule8.api.v0.subscription_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.PerformanceEventFilter)
  ))
_sym_db.RegisterMessage(PerformanceEventFilter)

ContainerEventFilter = _reflection.GeneratedProtocolMessageType('ContainerEventFilter', (_message.Message,), dict(
  DESCRIPTOR = _CONTAINEREVENTFILTER,
  __module__ = 'capsule8.api.v0.subscription_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.ContainerEventFilter)
  ))
_sym_db.RegisterMessage(ContainerEventFilter)

ChargenEventFilter = _reflection.GeneratedProtocolMessageType('ChargenEventFilter', (_message.Message,), dict(
  DESCRIPTOR = _CHARGENEVENTFILTER,
  __module__ = 'capsule8.api.v0.subscription_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.ChargenEventFilter)
  ))
_sym_db.RegisterMessage(ChargenEventFilter)

TickerEventFilter = _reflection.GeneratedProtocolMessageType('TickerEventFilter', (_message.Message,), dict(
  DESCRIPTOR = _TICKEREVENTFILTER,
  __module__ = 'capsule8.api.v0.subscription_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.TickerEventFilter)
  ))
_sym_db.RegisterMessage(TickerEventFilter)

Modifier = _reflection.GeneratedProtocolMessageType('Modifier', (_message.Message,), dict(
  DESCRIPTOR = _MODIFIER,
  __module__ = 'capsule8.api.v0.subscription_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.Modifier)
  ))
_sym_db.RegisterMessage(Modifier)

ThrottleModifier = _reflection.GeneratedProtocolMessageType('ThrottleModifier', (_message.Message,), dict(
  DESCRIPTOR = _THROTTLEMODIFIER,
  __module__ = 'capsule8.api.v0.subscription_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.ThrottleModifier)
  ))
_sym_db.RegisterMessage(ThrottleModifier)

LimitModifier = _reflection.GeneratedProtocolMessageType('LimitModifier', (_message.Message,), dict(
  DESCRIPTOR = _LIMITMODIFIER,
  __module__ = 'capsule8.api.v0.subscription_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.LimitModifier)
  ))
_sym_db.RegisterMessage(LimitModifier)


_KERNELFUNCTIONCALLFILTER_ARGUMENTSENTRY.has_options = True
_KERNELFUNCTIONCALLFILTER_ARGUMENTSENTRY._options = _descriptor._ParseOptions(descriptor_pb2.MessageOptions(), _b('8\001'))
# @@protoc_insertion_point(module_scope)
