# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: capsule8/api/v0/telemetry_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from capsule8.api.v0 import subscription_pb2 as capsule8_dot_api_dot_v0_dot_subscription__pb2
from capsule8.api.v0 import telemetry_event_pb2 as capsule8_dot_api_dot_v0_dot_telemetry__event__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='capsule8/api/v0/telemetry_service.proto',
  package='capsule8.api.v0',
  syntax='proto3',
  serialized_pb=_b('\n\'capsule8/api/v0/telemetry_service.proto\x12\x0f\x63\x61psule8.api.v0\x1a\"capsule8/api/v0/subscription.proto\x1a%capsule8/api/v0/telemetry_event.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/rpc/status.proto\"G\n\x10GetEventsRequest\x12\x33\n\x0csubscription\x18\x01 \x01(\x0b\x32\x1d.capsule8.api.v0.Subscription\"r\n\x11GetEventsResponse\x12\x37\n\x06\x65vents\x18\x01 \x03(\x0b\x32\'.capsule8.api.v0.ReceivedTelemetryEvent\x12$\n\x08statuses\x18\x02 \x03(\x0b\x32\x12.google.rpc.Status\"r\n\x16ReceivedTelemetryEvent\x12\x1b\n\x13publish_time_micros\x18\x01 \x01(\x03\x12.\n\x05\x65vent\x18\x02 \x01(\x0b\x32\x1f.capsule8.api.v0.TelemetryEvent\x12\x0b\n\x03\x61\x63k\x18\x03 \x01(\x0c\x32\x7f\n\x10TelemetryService\x12k\n\tGetEvents\x12!.capsule8.api.v0.GetEventsRequest\x1a\".capsule8.api.v0.GetEventsResponse\"\x15\x82\xd3\xe4\x93\x02\x0f\"\n/v0/events:\x01*0\x01\x62\x06proto3')
  ,
  dependencies=[capsule8_dot_api_dot_v0_dot_subscription__pb2.DESCRIPTOR,capsule8_dot_api_dot_v0_dot_telemetry__event__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_rpc_dot_status__pb2.DESCRIPTOR,])




_GETEVENTSREQUEST = _descriptor.Descriptor(
  name='GetEventsRequest',
  full_name='capsule8.api.v0.GetEventsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='subscription', full_name='capsule8.api.v0.GetEventsRequest.subscription', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=190,
  serialized_end=261,
)


_GETEVENTSRESPONSE = _descriptor.Descriptor(
  name='GetEventsResponse',
  full_name='capsule8.api.v0.GetEventsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='events', full_name='capsule8.api.v0.GetEventsResponse.events', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='statuses', full_name='capsule8.api.v0.GetEventsResponse.statuses', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=263,
  serialized_end=377,
)


_RECEIVEDTELEMETRYEVENT = _descriptor.Descriptor(
  name='ReceivedTelemetryEvent',
  full_name='capsule8.api.v0.ReceivedTelemetryEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='publish_time_micros', full_name='capsule8.api.v0.ReceivedTelemetryEvent.publish_time_micros', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='event', full_name='capsule8.api.v0.ReceivedTelemetryEvent.event', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ack', full_name='capsule8.api.v0.ReceivedTelemetryEvent.ack', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=379,
  serialized_end=493,
)

_GETEVENTSREQUEST.fields_by_name['subscription'].message_type = capsule8_dot_api_dot_v0_dot_subscription__pb2._SUBSCRIPTION
_GETEVENTSRESPONSE.fields_by_name['events'].message_type = _RECEIVEDTELEMETRYEVENT
_GETEVENTSRESPONSE.fields_by_name['statuses'].message_type = google_dot_rpc_dot_status__pb2._STATUS
_RECEIVEDTELEMETRYEVENT.fields_by_name['event'].message_type = capsule8_dot_api_dot_v0_dot_telemetry__event__pb2._TELEMETRYEVENT
DESCRIPTOR.message_types_by_name['GetEventsRequest'] = _GETEVENTSREQUEST
DESCRIPTOR.message_types_by_name['GetEventsResponse'] = _GETEVENTSRESPONSE
DESCRIPTOR.message_types_by_name['ReceivedTelemetryEvent'] = _RECEIVEDTELEMETRYEVENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetEventsRequest = _reflection.GeneratedProtocolMessageType('GetEventsRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETEVENTSREQUEST,
  __module__ = 'capsule8.api.v0.telemetry_service_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.GetEventsRequest)
  ))
_sym_db.RegisterMessage(GetEventsRequest)

GetEventsResponse = _reflection.GeneratedProtocolMessageType('GetEventsResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETEVENTSRESPONSE,
  __module__ = 'capsule8.api.v0.telemetry_service_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.GetEventsResponse)
  ))
_sym_db.RegisterMessage(GetEventsResponse)

ReceivedTelemetryEvent = _reflection.GeneratedProtocolMessageType('ReceivedTelemetryEvent', (_message.Message,), dict(
  DESCRIPTOR = _RECEIVEDTELEMETRYEVENT,
  __module__ = 'capsule8.api.v0.telemetry_service_pb2'
  # @@protoc_insertion_point(class_scope:capsule8.api.v0.ReceivedTelemetryEvent)
  ))
_sym_db.RegisterMessage(ReceivedTelemetryEvent)



_TELEMETRYSERVICE = _descriptor.ServiceDescriptor(
  name='TelemetryService',
  full_name='capsule8.api.v0.TelemetryService',
  file=DESCRIPTOR,
  index=0,
  options=None,
  serialized_start=495,
  serialized_end=622,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetEvents',
    full_name='capsule8.api.v0.TelemetryService.GetEvents',
    index=0,
    containing_service=None,
    input_type=_GETEVENTSREQUEST,
    output_type=_GETEVENTSRESPONSE,
    options=_descriptor._ParseOptions(descriptor_pb2.MethodOptions(), _b('\202\323\344\223\002\017\"\n/v0/events:\001*')),
  ),
])
_sym_db.RegisterServiceDescriptor(_TELEMETRYSERVICE)

DESCRIPTOR.services_by_name['TelemetryService'] = _TELEMETRYSERVICE

# @@protoc_insertion_point(module_scope)
